@Echo Off
Rem *****************************************************************************
Rem  Patch #1 for Service Profiler v1.3
Rem *****************************************************************************
Rem  Wrightia, S.A. (c) 2012
Rem
Rem  Purpose:
Rem     1. Replace all native libraries
Rem     2. Replace all server and static JAR libraries
Rem
Rem  Input parameters:
Rem     %1  : IS_DIR  (The Integration Server installation directory)
Rem
Rem  Results:
Rem     1. Applies Patch #1 for Service Profiler v1.3.
Rem
Rem  Exit codes:
Rem     0  - OK
Rem
Rem *****************************************************************************

SetLocal
PushD

If Exist ..\error (
   If Exist ..\error\*.upd.bat (
      Call :logWarning "Previous updates with error were found: %0 skipped."
      Exit /b 100
   )
) Else (
   MkDir ..\error
)

date /T >> updates.log
time /T >> updates.log

Set xISHome=%~1
Set xTargetHome=%xISHome%\serviceprofiler

If NOT Exist %xTargetHome% (
   Call :logWarning "Directory '%xTargetHome%' was not found: '%0' not applied."
   goto end-of-patch
) Else (
   RmDir /Q /S %xTargetHome%
)

   Rem replace previous installation on server folder
:Copy_1
   Call :log "Copying ..\..\serviceprofiler"
   MkDir "%xTargetHome%"
   XCopy /S /C /I ..\..\serviceprofiler "%xTargetHome%"        >> updates.log
   If ERRORLEVEL 0 (
      Goto Copy_2
   ) Else (
      Exit /b %ERRORLEVEL%
   )

:Copy_2
   Call :log "Copying WINDOWS libraries"
   Copy ..\..\serviceprofiler\lib\*.dll "%xTargetHome%\lib\"   >> updates.log
   If ERRORLEVEL 0 (
      Goto Copy_3
   ) Else (
      Exit /b %ERRORLEVEL%
   )

   Rem update (or create) Java libraries
:Copy_3
   Call :log "Copying Java libraries"
   Copy ..\..\serviceprofiler\lib\*.jar "%xTargetHome%\lib\"   >> updates.log
   If ERRORLEVEL 0 (
      Goto Copy_4
   ) Else (
      Exit /b %ERRORLEVEL%
   )

:Copy_4
   Call :log "Replace package-static Java libraries"
   move .\v1-3_patch1.core.jar ..\..\..\code\jars\static\wia-profiler-core-11.jar
   If NOT ERRORLEVEL 0 (
      Exit /b %ERRORLEVEL%
   )

:Copy_5
   Call :log "Replace package Java libraries"
   move .\v1-3_patch1.ispkg.jar ..\..\..\code\jars\wia-profiler-ispkg-11.jar
   If NOT ERRORLEVEL 0 (
      Exit /b %ERRORLEVEL%
   )

:end-of-patch

PopD
EndLocal

Exit /b 0


:log
   echo %~1 >> updates.log
   Goto :EOF

: logError
   Call :log "ERROR %~1"
   Goto :EOF

:logWarning
   Call :log "WARNING %~1"
   Goto :EOF

:logInfo
   Call :log "INFO %~1"
   Goto :EOF

